@@ -2,8 +2,10 @@
  "library"
  (lambda ()
    (LaTeX-add-bibitems
+    "gv13"
     "adh13"
     "akm18"
-    "bartik91"))
+    "bartik91"
+    "ass19"))
  :bibtex)
 
